@@ -65,6 +65,13 @@ then
 	VIRTUALENVWRAPPER_ENV_BIN_DIR="Scripts"
 fi
 
+# Let the user override the name of the file that holds the project
+# directory name.
+if [ "$VIRTUALENVWRAPPER_PROJECT_FILENAME" = "" ]
+then
+    export VIRTUALENVWRAPPER_PROJECT_FILENAME=".project"
+fi
+
 function virtualenvwrapper_derive_workon_home {
     typeset workon_home_dir="$WORKON_HOME"
 
@@ -204,6 +211,10 @@ function virtualenvwrapper_setup_tab_completion {
 
 # Set up virtualenvwrapper properly
 function virtualenvwrapper_initialize {
+    if [ ! -z "$VIRTUALENVWRAPPER_INITIALIZED" ]
+    then
+        return 0
+    fi
     export WORKON_HOME="$(virtualenvwrapper_derive_workon_home)"
 
     virtualenvwrapper_verify_workon_home -q || return 1
@@ -229,6 +240,9 @@ function virtualenvwrapper_initialize {
 
     virtualenvwrapper_setup_tab_completion
 
+    export VIRTUALENVWRAPPER_INITIALIZED=1
+
+    return 0
 }
 
 
@@ -271,7 +285,12 @@ function virtualenvwrapper_verify_active_environment {
 
 # Help text for mkvirtualenv
 function mkvirtualenv_help {
-    echo "Usage: mkvirtualenv [-i package] [-r requirements_file] [virtualenv options] env_name"
+    echo "Usage: mkvirtualenv [-a project_path] [-i package] [-r requirements_file] [virtualenv options] env_name"
+    echo
+    echo " -a project_path"
+    echo
+    echo "    Provide a full path to a project directory to associate with"
+    echo "    the new environment."
     echo
     echo " -i package"
     echo
@@ -318,6 +337,9 @@ function mkvirtualenv {
         a="${in_args[$i]}"
         # echo "arg $i : $a"
         case "$a" in
+            -a)
+                i=$(( $i + 1 ));
+                project="${in_args[$i]}";;
             -h)
                 mkvirtualenv_help;
                 return;;
@@ -370,6 +392,11 @@ function mkvirtualenv {
         pip install $a
     done
 
+    if [ ! -z "$project" ]
+    then
+        setvirtualenvproject "" "$project"
+    fi
+
     virtualenvwrapper_run_hook "post_mkvirtualenv"
 }
 
@@ -786,7 +813,7 @@ function setvirtualenvproject {
         prj="$(pwd)"
     fi
     echo "Setting project for $(basename $venv) to $prj"
-    echo "$prj" > "$venv/.project"
+    echo "$prj" > "$venv/$VIRTUALENVWRAPPER_PROJECT_FILENAME"
 }
 
 # Show help for mkproject
@@ -891,9 +918,9 @@ function mkproject {
 function cdproject {
     virtualenvwrapper_verify_workon_home || return 1
     virtualenvwrapper_verify_active_environment || return 1
-    if [ -f "$VIRTUAL_ENV/.project" ]
+    if [ -f "$VIRTUAL_ENV/$VIRTUALENVWRAPPER_PROJECT_FILENAME" ]
     then
-        project_dir=$(cat "$VIRTUAL_ENV/.project")
+        project_dir=$(cat "$VIRTUAL_ENV/$VIRTUALENVWRAPPER_PROJECT_FILENAME")
         if [ ! -z "$project_dir" ]
         then
             cd "$project_dir"
@@ -902,7 +929,7 @@ function cdproject {
             return 1
         fi
     else
-        echo "No project set in $VIRTUAL_ENV/.project" 1>&2
+        echo "No project set in $VIRTUAL_ENV/$VIRTUALENVWRAPPER_PROJECT_FILENAME" 1>&2
         return 1
     fi
     return 0
